@@ -48,15 +48,24 @@
 /* three seconds */
 #define TIMEOUT 3
 
-int btperror(char *text, int fatal=0);
+#include <X11/Xlib.h>
+
+#include "btp.h"
+/* --------------------------------- These are now in btp.h */
+// extern void beep(int pitch, int duration, int permLevel);
+// extern int btperror(char *text, int fatal=0);
+
+int fd; // The socket.
 int timeout=0;
 char *progname;
 
+/* --------------------------------------------------------------- */
 void sigalrm(int sig)
 {
 	timeout=1;
 }
 
+/* --------------------------------------------------------------- */
 const char *read_string(int fd)
 {
 	static char buffer[PACKET_SIZE+1]="";
@@ -113,6 +122,7 @@ const char *read_string(int fd)
 	return(buffer);
 }
 
+/* --------------------------------------------------------------- */
 enum packet_state
 {
 	P_BEGIN,
@@ -247,6 +257,7 @@ int send_packet(int fd,const char *packet)
 	return(-1);
 }
 
+/* --------------------------------------------------------------- */
 int valsend(int fd, char *command) {
   char buffer[PACKET_SIZE+1];
 
@@ -254,9 +265,11 @@ int valsend(int fd, char *command) {
     sprintf(buffer,"SEND_ONCE %s\n",command);
     
     if(send_packet(fd,buffer)==-1) {
-      btperror("Could not send\ncommand");
+      btperror("Could not send command");
       close(fd);
       return(EXIT_FAILURE);
+    } else {
+      beep(800, 25, 2);
     }
   } else {
     btperror("Input too long");
@@ -266,7 +279,8 @@ int valsend(int fd, char *command) {
   return(EXIT_SUCCESS);
 }
 
-int rcsend(char *command, int fd)
+/* --------------------------------------------------------------- */
+int rcsend(char *command)
 {
 ///     struct sockaddr_un addr;
 	//      int fd;
@@ -291,25 +305,25 @@ int rcsend(char *command, int fd)
        	act.sa_flags=0;           /* we need EINTR */
        	sigaction(SIGALRM,&act,NULL);
 
-	//       	addr.sun_family=AF_UNIX;
-	//	strcpy(addr.sun_path,LIRCD);
-	//	fd=socket(AF_UNIX,SOCK_STREAM,0);
-	//	if(fd==-1)
-	//	{
-	//	   btperror("Could not open\nsocket\n\nIs lircd running?");
-	//	   // I know, but I really don't like applications just dying.
-	//	   // 		   perror(progname);
-	//	   // 		   exit(EXIT_FAILURE);
-	//	   return(EXIT_FAILURE);
-	//	};
-	//	if(connect(fd,(struct sockaddr *)&addr,sizeof(addr))==-1)
-	//	{
-	//	  btperror("Could not connect\nto socket\n\nIs lircd running?");
-	//	   // Same goes here.
-	//	   //		   perror(progname);
-	//	   //		   exit(EXIT_FAILURE);
-	//	   return(EXIT_FAILURE);
-	//	};
+	//  	addr.sun_family=AF_UNIX;
+	// strcpy(addr.sun_path,LIRCD);
+	// fd=socket(AF_UNIX,SOCK_STREAM,0);
+	// if(fd==-1)
+	// {
+	//    btperror("Could not open\nsocket\n\nIs lircd running?");
+	//    // I know, but I really don't like applications just dying.
+	//    // 		   perror(progname);
+	//    // 		   exit(EXIT_FAILURE);
+	//    return(EXIT_FAILURE);
+	// };
+	// if(connect(fd,(struct sockaddr *)&addr,sizeof(addr))==-1)
+	// {
+	//   btperror("Could not connect\nto socket\n\nIs lircd running?");
+	//    // Same goes here.
+	//    //		   perror(progname);
+	//    //		   exit(EXIT_FAILURE);
+	//    return(EXIT_FAILURE);
+	// };
 
 	if(!strncasecmp(command, "macro ", 6)) {
 	  //Ok... I really hate string juggling.
@@ -357,3 +371,23 @@ int rcsend(char *command, int fd)
 	//	close(fd);
 	return(sendstatus);
 }
+
+/* ------------------------------------------------ Open  the socket */
+void startRc() {
+struct sockaddr_un addr;
+// This bit is from rcsend. I want to get rid of the (probably miniscule)
+// overhead of opening and connecting to the socket for every command.
+  addr.sun_family = AF_UNIX;
+  strcpy(addr.sun_path,LIRCD);
+  fd = socket(AF_UNIX,SOCK_STREAM,0);
+  if(fd==-1) btperror("Could not open socket\n\nIs lircd running?", 1);
+
+  if(connect(fd,(struct sockaddr *)&addr,sizeof(addr))==-1)
+       btperror("Could not connect to socket\n\nIs lircd running?", 1);
+// Bit end. endRc() will take care of closing fd for us.
+}
+
+/* ------------------------------------------------ Close the socket */
+void endRc() {
+  close(fd);
+}
